@@ -776,7 +776,7 @@ class GraphSet(object):
         """Adds a given graph or edge to `self`.
 
         If a graph is given, the graph is just added to `self`
-        GraphSet.  If an edge is given, the edge is added to all the
+        GraphSet.  If an edge is given, the edge is grafted to all the
         graphs in `self`.  The `self` will be changed.
 
         Examples:
@@ -1266,7 +1266,7 @@ class GraphSet(object):
 #        return GraphSet(self._ss.non_supersets(other._ss))
 
     def including(self, obj):
-        """Returns a new GraphSet that includes `obj`.
+        """Returns a new GraphSet that includes supergraphs of `obj`.
 
         Returns a new set of graphs that include `obj`, which can be a
         GraphSet, a graph, an edge, or a vertex.  If `obj` is a
@@ -1444,7 +1444,8 @@ class GraphSet(object):
         """
         return self._ss.dumps()
 
-    def load(self, fp):
+    @staticmethod
+    def load(fp):
         """Deserialize a file `fp` to `self`.
 
         This method does not deserialize the universe, which should be
@@ -1458,14 +1459,15 @@ class GraphSet(object):
           >>> fp = open('/path/to/universe')
           >>> GraphSet.set_universe(pickle.load(fp))
           >>> fp = open('/path/to/graphset')
-          >>> gs = GraphSet().load(fp)
+          >>> gs = GraphSet.load(fp)
 
         See Also:
           loads(), dump()
         """
-        return self._ss.load(fp)
+        return GraphSet(setset.load(fp))
 
-    def loads(self, s):
+    @staticmethod
+    def loads(s):
         """Deserialize `s` to `self`.
 
         This method does not deserialize the universe, which should be
@@ -1477,12 +1479,12 @@ class GraphSet(object):
         Examples:
           >>> import pickle
           >>> GraphSet.set_universe(pickle.loads(universe_str))
-          >>> gs = Graphset().load(graphset_str)
+          >>> gs = GraphSet.load(graphset_str)
 
         See Also:
           load(), dumps()
         """
-        return self._ss.loads(s)
+        return GraphSet(setset.loads(s))
 
     @staticmethod
     def set_universe(universe, traversal='bfs', source=None):
@@ -1591,7 +1593,8 @@ class GraphSet(object):
           A new GraphSet object.
         """
         graph = []
-        for e in GraphSet.universe():
+        for e in setset.universe():
+            assert e[0] in GraphSet._vertices and e[1] in GraphSet._vertices
             graph.append((pickle.dumps(e[0]), pickle.dumps(e[1])))
 
         vg = []
