@@ -76,7 +76,7 @@ class setset {
    protected:
     virtual void next();
 
-    intx_t size_;
+    double size_;
   };
 
   class weighted_iterator : public iterator {
